@@ -26,20 +26,17 @@ def cli():
 @click.option('--freq', '-f', required=True, type=click.Choice(['4h', '1h']), help="frquency to use")
 @click.option('--res_dir', '-r', required=True, type=str, help="directory for outputs")
 @click.option('--flag_filter', '-g', type=str, default=None, show_default=True, help='flag to use, mmi | ang')
-@click.option('--flag_ts_stop', '-t', is_flag=True, help='ts_stop flag')
-def best_ma_strategy(symbol, freq, res_dir, flag_filter, flag_ts_stop):
+@click.option('--flag_stop', '-t', type=str, default=None, show_default=True, help='early stop flag, ts_stop | sl_stop | tp_stop')
+def best_ma_strategy(symbol, freq, res_dir, flag_filter, flag_stop):
     parts = res_dir.split('-')
     if freq not in parts:
         raise ValueError('Mismatch found in freq setting and output dir')
     if (flag_filter and flag_filter not in parts) or (not flag_filter and 'filter' in parts):
         raise ValueError('Mismatch found in filter setting and output dir')
-    if flag_ts_stop and 'ts_stop' not in parts:
-        raise ValueError('Mismatch found in ts_stop setting and output dir')
-    if symbol:
-        symbols = [symbol]
-    else:
-        symbols = SYMBOLS
-    BestMaStrategy(symbols, freq, res_dir, flag_filter, flag_ts_stop)
+    if flag_stop and 'stop' not in res_dir:
+        raise ValueError('Mismatch found in flag_stop setting and output dir')
+    symbols = symbol if symbol else SYMBOLS
+    BestMaStrategy(symbols, freq, res_dir, flag_filter, flag_stop)
 
 
 @cli.command()
@@ -47,20 +44,17 @@ def best_ma_strategy(symbol, freq, res_dir, flag_filter, flag_ts_stop):
 @click.option('--date', '-d', type=str, help='the date when the results are generated')
 @click.option('--res_dir', '-r', required=True, type=str, help='directory for outputs')
 @click.option('--flag_filter', '-g', type=str, default=None, show_default=True, help='flag to use, mmi | ang')
-@click.option('--flag_ts_stop', '-t', is_flag=True, help='ts_stop flag')
-def check_ma_indicators(symbol, date, res_dir, flag_filter, flag_ts_stop):
+@click.option('--flag_stop', '-t', type=str, default=None, show_default=True, help='early stop flag, ts_stop | sl_stop | tp_stop')
+def check_ma_indicators(symbol, date, res_dir, flag_filter, flag_stop):
     parts = res_dir.split('-')
     if (flag_filter and flag_filter not in parts) or (not flag_filter and 'filter' in parts):
         raise ValueError('Mismatch found in filter setting and output dir')
     if 'ma' not in parts:
         raise ValueError('Make sure the res_dir is for MA strategy')
-    if flag_ts_stop and 'ts_stop' not in parts:
-        raise ValueError('Mismatch found in ts_stop setting and output dir')
-    if symbol:
-        symbols = [symbol]
-    else:
-        symbols = SYMBOLS
-    CheckMaIndicators(symbols, date, res_dir, flag_filter, flag_ts_stop)
+    if flag_stop and 'stop' not in res_dir:
+        raise ValueError('Mismatch found in flag_stop setting and output dir')
+    symbols = symbol if symbol else SYMBOLS
+    CheckMaIndicators(symbols, date, res_dir, flag_filter, flag_stop)
 
 
 @cli.command()
@@ -68,8 +62,8 @@ def check_ma_indicators(symbol, date, res_dir, flag_filter, flag_ts_stop):
 @click.option('--freq', '-f', required=True, type=click.Choice(['4h', '1h']), help="frquency to use")
 @click.option('--res_dir', '-r', required=True, type=str, help="directory for outputs")
 @click.option('--flag_filter', '-g', type=str, default=None, show_default=True, help='filter to use, vol | ang')
-@click.option('--flag_ts_stop', '-t', is_flag=True, help='ts_stop flag')
-def best_bo_strategy(symbol, freq, res_dir, flag_filter, flag_ts_stop):
+@click.option('--flag_stop', '-t', type=str, default=None, show_default=True, help='early stop flag, ts_stop | sl_stop | tp_stop')
+def best_bo_strategy(symbol, freq, res_dir, flag_filter, flag_stop):
     parts = res_dir.split('-')
     if freq not in parts:
         raise ValueError('Mismatch found in freq setting and output dir')
@@ -77,13 +71,10 @@ def best_bo_strategy(symbol, freq, res_dir, flag_filter, flag_ts_stop):
         raise ValueError('Mismatch found in filter setting and output dir')
     if 'bo' not in parts:
         raise ValueError('Mismatch found in strategy bo and output dir')
-    if flag_ts_stop and 'ts_stop' not in parts:
+    if flag_stop and 'ts_stop' not in parts:
         raise ValueError('Mismatch found in ts_stop setting and output dir')
-    if symbol:
-        symbols = [symbol]
-    else:
-        symbols = SYMBOLS
-    BestBoStrategy(symbols, freq, res_dir, flag_filter, flag_ts_stop)
+    symbols = symbol if symbol else SYMBOLS
+    BestBoStrategy(symbols, freq, res_dir, flag_filter, flag_stop)
 
 
 @cli.command()
@@ -91,20 +82,17 @@ def best_bo_strategy(symbol, freq, res_dir, flag_filter, flag_ts_stop):
 @click.option('--date', '-d', type=str, help='the date when the results are generated')
 @click.option('--res_dir', '-r', required=True, type=str, help="directory for outputs")
 @click.option('--flag_filter', '-g', type=str, default=None, show_default=True, help='filter to use, vol | ang')
-@click.option('--flag_ts_stop', '-t', is_flag=True, help='ts_stop flag')
-def check_bo_indicators(symbol, date, res_dir, flag_filter, flag_ts_stop):
+@click.option('--flag_stop', '-t', type=str, default=None, show_default=True, help='early stop flag, ts_stop | sl_stop | tp_stop')
+def check_bo_indicators(symbol, date, res_dir, flag_filter, flag_stop):
     parts = res_dir.split('-')
     if (flag_filter and flag_filter not in parts) or (not flag_filter and 'filter' in parts):
         raise ValueError('Mismatch found in filter setting and output dir')
     if 'bo' not in parts:
         raise ValueError('Mismatch found in strategy bo and output dir')
-    if flag_ts_stop and 'ts_stop' not in parts:
+    if flag_stop and 'ts_stop' not in parts:
         raise ValueError('Mismatch found in ts_stop setting and output dir')
-    if symbol:
-        symbols = [symbol]
-    else:
-        symbols = SYMBOLS
-    CheckBoIndicators(symbols, date, res_dir, flag_filter, flag_ts_stop)
+    symbols = symbol if symbol else SYMBOLS
+    CheckBoIndicators(symbols, date, res_dir, flag_filter, flag_stop)
 
 
 @cli.command()
